==> common-3.5.3-sources.jar: com/weicoder/common/constants/StringConstants.java <==
package com.weicoder.common.constants;

/**
 * 字符串常量
 * 
 * @author WD
 */
public class StringConstants {
	/** 常量字符串 "" */
	public final static String	EMPTY				= "";
	/** 常量字符串 " " */
	public final static String	BLANK				= " ";
	/** 常量字符串 "." */
	public final static String	POINT				= ".";
	/** 常量字符串 "_" */
	public final static String	UNDERLINE			= "_";
	/** 常量字符串 "-" */
	public final static String	LINE				= "-";
	/** 常量字符串 "," */
	public final static String	COMMA				= ",";
	/** 常量字符串 ":" */
	public final static String	COLON				= ":";
	/** 常量字符串 "/" */
	public final static String	BACKSLASH			= "/";
	/** 常量字符串 "key" */
	public final static String	KEY					= "key";
	/** 常量字符串 "*" */
	public final static String	ASTERISK			= "*";
	/** 常量字符串 "key" */
	public final static String	SEPA				= "`";
	/** 常量字符串 "success" */
	public final static String	SUCCESS				= "success";
	/** 常量字符串 "fail" */
	public final static String	FAIL				= "fail";
	/** 常量字符串 "error" */
	public final static String	ERROR				= "error";
	/** 常量字符串 "0" */
	public final static String	ZERO				= "0";
	/** 常量字符串 "\\." */
	public final static String	DOT					= "\\.";
	/** 常量字符串 "-" */
	public final static String	MIDLINE				= "-";
	/** 常量字符串 "#" */
	public final static String	WELL				= "#";
	/** 常量字符串 ";" */
	public final static String	SEMICOLON			= ";";
	/** 常量字符串 "\" */
	public final static String	DIAGONAL			= "\\";
	/** 常量字符串 "\\r" */
	public final static String	ENTER				= "\r";
	/** 常量字符串 "\\n" */
	public final static String	NEWLINE				= "\n";
	/** 常量字符串 "<" */
	public final static String	LT					= "<";
	/** 常量字符串 ">" */
	public final static String	GT					= ">";
	/** 常量字符串 "\"" */
	public final static String	QUOT				= "\"";
	/** 常量字符串"'" */
	public final static String	SINGLE_QUOT			= "'";
	/** 常量字符串""" */
	public final static String	DOUBLE_QUOT			= "\"";
	/** 常量字符串"''" */
	public final static String	TWO_SINGLE_QUOT		= "''";
	/** 常量字符串"(" */
	public final static String	LEFT_PARENTHESIS	= "(";
	/** 常量字符串")" */
	public final static String	RIGHT_PARENTHESIS	= ")";
	/** 常量字符串 "true" */
	public final static String	TRUE				= "true";
	/** 常量字符串 "false" */
	public final static String	FALSE				= "false";
	/** 常量字符串 "yes" */
	public final static String	YES					= "yes";
	/** 常量字符串 "no" */
	public final static String	NO					= "no";
	/** 常量字符串 "ok" */
	public final static String	OK					= "ok";
	/** 常量字符串 "bad" */
	public final static String	BAD					= "bad";
	/** 常量字符串 "default" */
	public final static String	DEFAULT				= "default";
	/** 常量字符串 "set" */
	public final static String	SET					= "set";
	/** 常量字符串 "get" */
	public final static String	GET					= "get";
	/** 常量字符串 "id" */
	public final static String	ID					= "id";
	/** 常量字符串 "url" */
	public final static String	URL					= "url";
	/** 常量字符串 "java" */
	public final static String	JAVA				= "java";
	/** 常量字符串 "bytes" */
	public final static String	BYTES				= "bytes";
	/** 常量字符串 "hour" */
	public final static String	HOUR				= "hour";
	/** 常量字符串 "day" */
	public final static String	DAY					= "day";
	/** 常量字符串 "year" */
	public final static String	YEAR				= "year";
	/** 常量字符串 "date" */
	public final static String	DATE				= "date";
	/** 常量字符串 "month" */
	public final static String	MONTH				= "month";
	/** 常量字符串 "result" */
	public final static String	RESULT				= "result";
	/** 常量字符串 "content" */
	public final static String	CONTENT				= "content";
	/** 常量字符串 "classpath:" */
	public final static String	CLASS_PATH			= "classpath:";
	/** 常量字符串 "=" */
	public final static String	EQ					= "=";
	/** 常量字符串"?" */
	public final static String	QUESTION_MARK		= "?";
	/** 常量字符串 "value" */
	public final static String	VALUE				= "value";
	/** 常量字符串 "&" */
	public final static String	AMP					= "&";
}

==> common-3.6.1-sources.jar: com/weicoder/common/constants/StringConstants.java <==
package com.weicoder.common.constants;

/**
 * 字符串常量
 * 
 * @author WD
 */
public sealed class StringConstants permits C.S {
	/** 常量字符串 "" */
	public final static String	EMPTY				= "";
	/** 常量字符串 " " */
	public final static String	BLANK				= " ";
	/** 常量字符串 "." */
	public final static String	POINT				= ".";
	/** 常量字符串 "_" */
	public final static String	UNDERLINE			= "_";
	/** 常量字符串 "-" */
	public final static String	LINE				= "-";
	/** 常量字符串 "," */
	public final static String	COMMA				= ",";
	/** 常量字符串 ":" */
	public final static String	COLON				= ":";
	/** 常量字符串 "/" */
	public final static String	BACKSLASH			= "/";
	/** 常量字符串 "key" */
	public final static String	KEY					= "key";
	/** 常量字符串 "*" */
	public final static String	ASTERISK			= "*";
	/** 常量字符串 "key" */
	public final static String	SEPA				= "`";
	/** 常量字符串 "success" */
	public final static String	SUCCESS				= "success";
	/** 常量字符串 "fail" */
	public final static String	FAIL				= "fail";
	/** 常量字符串 "error" */
	public final static String	ERROR				= "error";
	/** 常量字符串 "0" */
	public final static String	ZERO				= "0";
	/** 常量字符串 "\\." */
	public final static String	DOT					= "\\.";
	/** 常量字符串 "#" */
	public final static String	WELL				= "#";
	/** 常量字符串 ";" */
	public final static String	SEMICOLON			= ";";
	/** 常量字符串 "\" */
	public final static String	DIAGONAL			= "\\";
	/** 常量字符串 "\\r" */
	public final static String	ENTER				= "\r";
	/** 常量字符串 "\\n" */
	public final static String	NEWLINE				= "\n";
	/** 常量字符串 "<" */
	public final static String	LT					= "<";
	/** 常量字符串 ">" */
	public final static String	GT					= ">";
	/** 常量字符串 "\"" */
	public final static String	QUOT				= "\"";
	/** 常量字符串"'" */
	public final static String	SINGLE_QUOT			= "'";
	/** 常量字符串""" */
	public final static String	DOUBLE_QUOT			= "\"";
	/** 常量字符串"''" */
	public final static String	TWO_SINGLE_QUOT		= "''";
	/** 常量字符串"(" */
	public final static String	LEFT_PARENTHESIS	= "(";
	/** 常量字符串")" */
	public final static String	RIGHT_PARENTHESIS	= ")";
	/** 常量字符串 "true" */
	public final static String	TRUE				= "true";
	/** 常量字符串 "false" */
	public final static String	FALSE				= "false";
	/** 常量字符串 "yes" */
	public final static String	YES					= "yes";
	/** 常量字符串 "no" */
	public final static String	NO					= "no";
	/** 常量字符串 "ok" */
	public final static String	OK					= "ok";
	/** 常量字符串 "bad" */
	public final static String	BAD					= "bad";
	/** 常量字符串 "default" */
	public final static String	DEFAULT				= "default";
	/** 常量字符串 "set" */
	public final static String	SET					= "set";
	/** 常量字符串 "get" */
	public final static String	GET					= "get";
	/** 常量字符串 "id" */
	public final static String	ID					= "id";
	/** 常量字符串 "url" */
	public final static String	URL					= "url";
	/** 常量字符串 "java" */
	public final static String	JAVA				= "java";
	/** 常量字符串 "bytes" */
	public final static String	BYTES				= "bytes";
	/** 常量字符串 "hour" */
	public final static String	HOUR				= "hour";
	/** 常量字符串 "day" */
	public final static String	DAY					= "day";
	/** 常量字符串 "year" */
	public final static String	YEAR				= "year";
	/** 常量字符串 "date" */
	public final static String	DATE				= "date";
	/** 常量字符串 "month" */
	public final static String	MONTH				= "month";
	/** 常量字符串 "result" */
	public final static String	RESULT				= "result";
	/** 常量字符串 "content" */
	public final static String	CONTENT				= "content";
	/** 常量字符串 "classpath:" */
	public final static String	CLASS_PATH			= "classpath:";
	/** 常量字符串 "=" */
	public final static String	EQ					= "=";
	/** 常量字符串"?" */
	public final static String	QUESTION_MARK		= "?";
	/** 常量字符串 "value" */
	public final static String	VALUE				= "value";
	/** 常量字符串 "&" */
	public final static String	AMP					= "&";
}
